@@ -57,6 +57,25 @@ class Device(models.Model):
         verbose_name = _(u"Device status"),
     )
 
+    def __unicode__(self):
+        return self.hostname
+
+    @models.permalink
+    def get_absolute_url(self):
+        return ("lava.scheduler.device.detail", [self.pk])
+
+    def recent_jobs(self):
+        return TestJob.objects.select_related(
+            "actual_device",
+            "requested_device",
+            "requested_device_type",
+            "submitter",
+        ).filter(
+            actual_device=self
+        ).order_by(
+            '-start_time'
+        )
+
     def can_admin(self, user):
         return user.has_perm('lava_scheduler_app.change_device')
 
@@ -71,9 +90,6 @@ class Device(models.Model):
         self.status = self.IDLE
         self.save()
 
-    def __unicode__(self):
-        return self.hostname
-
     #@classmethod
     #def find_devices_by_type(cls, device_type):
     #    return device_type.device_set.all()
@@ -169,6 +185,10 @@ class TestJob(models.Model):
             r += " for %s" % (self.requested_device.hostname,)
         return r
 
+    @models.permalink
+    def get_absolute_url(self):
+        return ("lava.scheduler.job.detail", [self.pk])
+
     @classmethod
     def from_json_and_user(cls, json_data, user):
         job_data = simplejson.loads(json_data)
