@@ -4,7 +4,7 @@ from twisted.application.service import Service
 from twisted.internet import defer
 from twisted.internet.task import LoopingCall
 
-from lava_scheduler_daemon.board import Board
+from lava_scheduler_daemon.board import Board, catchall_errback
 
 
 class BoardSet(Service):
@@ -21,7 +21,8 @@ class BoardSet(Service):
 
     def _updateBoards(self):
         self.logger.debug("Refreshing board list")
-        return self.source.getBoardList().addCallback(self._cbUpdateBoards)
+        return self.source.getBoardList().addCallback(
+            self._cbUpdateBoards).addErrback(catchall_errback(self.logger))
 
     def _cbUpdateBoards(self, board_names):
         if set(board_names) == set(self.boards):
